#include <libgda/libgda.h>
#include <sql-parser/gda-sql-parser.h>

int main()
{
	gda_init();

	GdaConnection* connection;
	GdaSqlParser *parser;
	GdaStatement *stmt;
	GdaDataModel *model;
	GError *error = NULL;

	connection = gda_connection_open_from_dsn ("SalesTest", NULL, 0, &error);

	if (!connection) {
		g_print ("Connection failed: %s\n", error && error->message ? error->message : "No detail");
		return EXIT_FAILURE;
	}
 
	g_print ("Connection ok.\n");
	parser = gda_sql_parser_new ();
	stmt = gda_sql_parser_parse_string (parser, "SELECT load_extension('libext.so')", NULL, NULL);
	g_assert (stmt);
	model = gda_connection_statement_execute_select (connection, stmt, NULL, &error);
	g_object_unref (stmt);
	if (!model) {
		g_print ("load_extension failed: %s\n",
			 error && error->message ? error->message : "No detail");
		return EXIT_FAILURE;
	}
	gda_data_model_dump (model, NULL);
	g_object_unref (model);

	stmt = gda_sql_parser_parse_string (parser, "SELECT half (5)", NULL, NULL);
	g_assert (stmt);
	model = gda_connection_statement_execute_select (connection, stmt, NULL, &error);
	g_object_unref (stmt);
	if (!model) {
		g_print ("SELECT failed: %s\n",
			 error && error->message ? error->message : "No detail");
		return EXIT_FAILURE;
	}
	gda_data_model_dump (model, NULL);
	g_object_unref (model);
	
	
	gda_connection_close (connection);
	g_object_unref (connection);
	
	return EXIT_SUCCESS;
}
